summaryrefslogtreecommitdiffstats
path: root/src/Blocks/BlockSapling.h
diff options
context:
space:
mode:
authorTiger Wang <ziwei.tiger@hotmail.co.uk>2014-07-17 23:26:53 +0200
committerTiger Wang <ziwei.tiger@hotmail.co.uk>2014-07-17 23:26:53 +0200
commit0f8c24e04d60aa1642a5fe7346941ccd7697977e (patch)
tree4b62903944643bfe406f503393bc26815c2548a7 /src/Blocks/BlockSapling.h
parentFixed mob knockback (diff)
downloadcuberite-0f8c24e04d60aa1642a5fe7346941ccd7697977e.tar
cuberite-0f8c24e04d60aa1642a5fe7346941ccd7697977e.tar.gz
cuberite-0f8c24e04d60aa1642a5fe7346941ccd7697977e.tar.bz2
cuberite-0f8c24e04d60aa1642a5fe7346941ccd7697977e.tar.lz
cuberite-0f8c24e04d60aa1642a5fe7346941ccd7697977e.tar.xz
cuberite-0f8c24e04d60aa1642a5fe7346941ccd7697977e.tar.zst
cuberite-0f8c24e04d60aa1642a5fe7346941ccd7697977e.zip
Diffstat (limited to 'src/Blocks/BlockSapling.h')
-rw-r--r--src/Blocks/BlockSapling.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Blocks/BlockSapling.h b/src/Blocks/BlockSapling.h
index 3d925029a..e965809a3 100644
--- a/src/Blocks/BlockSapling.h
+++ b/src/Blocks/BlockSapling.h
@@ -20,8 +20,8 @@ public:
virtual void ConvertToPickups(cItems & a_Pickups, NIBBLETYPE a_BlockMeta) override
{
- // Only the first 2 bits contain the display information, the others are for growing
- a_Pickups.push_back(cItem(E_BLOCK_SAPLING, 1, a_BlockMeta & 3));
+ // Only the first 5 bits contain the display information, 8th bit for growth indicator (but we use 0x07 for forward compatibility)
+ a_Pickups.push_back(cItem(E_BLOCK_SAPLING, 1, a_BlockMeta & 0x07));
}